@@ -595,7 +595,7 @@ e_datazoom <- function(e, x_index = NULL, y_index = NULL, toolbox = TRUE, ...) {
 #'       c(180, -40)
 #'     )
 #'   ) |>
-#'   e_scatter(lat, mag, stations, coord.system = "geo", name = "mag") |>
+#'   e_scatter(lat, mag, stations, coord_system = "geo", name = "mag") |>
 #'   e_data(quakes, depth) |>
 #'   e_scatter(mag, mag, stations, name = "mag & depth") |>
 #'   e_grid(right = 40, top = 100, width = "30%") |>
@@ -700,7 +700,7 @@ e_title <- function(e, text = NULL, subtext = NULL, link = NULL, sublink = NULL,
 #'   e_polar() |>
 #'   e_angle_axis() |>
 #'   e_radius_axis() |>
-#'   e_line(y, coord.system = "polar", smooth = TRUE)
+#'   e_line(y, coord_system = "polar", smooth = TRUE)
 #' @seealso \href{https://echarts.apache.org/en/option.html#polar}{Additional arguments}
 #'
 #' @export
@@ -897,7 +897,6 @@ e_flip_coords <- function(e) {
 #'
 #' @inheritParams e_bar
 #'
-#' @note Do not use \code{e_arrange} in R markdown or Shiny.
 #'
 #' @seealso \href{https://echarts.apache.org/en/option.html#textStyle}{official documentation}
 #'
@@ -929,7 +928,7 @@ e_text_style <- function(e, ...) {
 #' @param ids Scalar, vector or list of ids of chart to connect with.
 #' @param rows,cols Number of rows and columns.
 #' @param ... Any \code{echarts} objects.
-#' @param width Wdith of columns, one of \code{xs}, \code{md}, \code{lg}.
+#' @param width Width of columns, one of \code{xs}, \code{md}, \code{lg}.
 #' @param group Group name.
 #' @param title Title of charts.
 #'
@@ -1053,10 +1052,10 @@ e_arrange <- function(..., rows = NULL, cols = NULL, width = "xs", title = NULL)
         class = "container-fluid",
         htmltools::tags$head(
           htmltools::tags$link(
-            rel = "stylesheet",
-            href = "https://stackpath.bootstrapcdn.com/bootstrap/4.1.3/css/bootstrap.min.css",
-            integrity = "sha384-MCw98/SFnGE8fJT3GXwEOngsV7Zt27NXFoaoApmYm81iuXoPkFOJwJ8ERdknLPMO",
-            crossorigin = "anonymous"
+            rel="stylesheet",
+            href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.7/dist/css/bootstrap.min.css",
+            integrity="sha384-LN+7fdVzj6u52u30Kp6M/trliBMCMKTyK833zpbD+pXdCLuTusPj697FH4R/5mcr",
+            crossorigin="anonymous"
           )
         ),
         htmltools::h3(title),
@@ -1179,4 +1178,4 @@ e_locale_manual <- function(e, locale, path){
 
   e$x$mainOpts$locale <- locale
   return(e)
-}
\ No newline at end of file
+}
